==> gorilla-notebook-0.4.0.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.storage.file.js <==
goog.provide('pinkgorilla.storage.file');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('pinkgorilla.storage.storage');

/**
* @constructor
 * @implements {cljs.core.IRecord}
 * @implements {cljs.core.IKVReduce}
 * @implements {cljs.core.IEquiv}
 * @implements {cljs.core.IHash}
 * @implements {cljs.core.ICollection}
 * @implements {cljs.core.ICounted}
 * @implements {cljs.core.ISeqable}
 * @implements {cljs.core.IMeta}
 * @implements {cljs.core.ICloneable}
 * @implements {cljs.core.IPrintWithWriter}
 * @implements {cljs.core.IIterable}
 * @implements {cljs.core.IWithMeta}
 * @implements {cljs.core.IAssociative}
 * @implements {cljs.core.IMap}
 * @implements {cljs.core.ILookup}
*/
pinkgorilla.storage.file.StorageFile = (function (filename,__meta,__extmap,__hash){
this.filename = filename;
this.__meta = __meta;
this.__extmap = __extmap;
this.__hash = __hash;
this.cljs$lang$protocol_mask$partition0$ = 2230716170;
this.cljs$lang$protocol_mask$partition1$ = 139264;
});
(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ILookup$_lookup$arity$2 = (function (this__4439__auto__,k__4440__auto__){
var self__ = this;
var this__4439__auto____$1 = this;
return this__4439__auto____$1.cljs$core$ILookup$_lookup$arity$3(null,k__4440__auto__,null);
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ILookup$_lookup$arity$3 = (function (this__4441__auto__,k27505,else__4442__auto__){
var self__ = this;
var this__4441__auto____$1 = this;
var G__27555 = k27505;
var G__27555__$1 = (((G__27555 instanceof cljs.core.Keyword))?G__27555.fqn:null);
switch (G__27555__$1) {
case "filename":
return self__.filename;

break;
default:
return cljs.core.get.cljs$core$IFn$_invoke$arity$3(self__.__extmap,k27505,else__4442__auto__);

}
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IKVReduce$_kv_reduce$arity$3 = (function (this__4458__auto__,f__4459__auto__,init__4460__auto__){
var self__ = this;
var this__4458__auto____$1 = this;
return cljs.core.reduce.cljs$core$IFn$_invoke$arity$3((function (ret__4461__auto__,p__27565){
var vec__27566 = p__27565;
var k__4462__auto__ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__27566,(0),null);
var v__4463__auto__ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__27566,(1),null);
return (f__4459__auto__.cljs$core$IFn$_invoke$arity$3 ? f__4459__auto__.cljs$core$IFn$_invoke$arity$3(ret__4461__auto__,k__4462__auto__,v__4463__auto__) : f__4459__auto__.call(null,ret__4461__auto__,k__4462__auto__,v__4463__auto__));
}),init__4460__auto__,this__4458__auto____$1);
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IPrintWithWriter$_pr_writer$arity$3 = (function (this__4453__auto__,writer__4454__auto__,opts__4455__auto__){
var self__ = this;
var this__4453__auto____$1 = this;
var pr_pair__4456__auto__ = (function (keyval__4457__auto__){
return cljs.core.pr_sequential_writer(writer__4454__auto__,cljs.core.pr_writer,""," ","",opts__4455__auto__,keyval__4457__auto__);
});
return cljs.core.pr_sequential_writer(writer__4454__auto__,pr_pair__4456__auto__,"#pinkgorilla.storage.file.StorageFile{",", ","}",opts__4455__auto__,cljs.core.concat.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"filename","filename",-1428840783),self__.filename],null))], null),self__.__extmap));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IIterable$_iterator$arity$1 = (function (G__27504){
var self__ = this;
var G__27504__$1 = this;
return (new cljs.core.RecordIter((0),G__27504__$1,1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"filename","filename",-1428840783)], null),(cljs.core.truth_(self__.__extmap)?cljs.core._iterator(self__.__extmap):cljs.core.nil_iter())));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IMeta$_meta$arity$1 = (function (this__4437__auto__){
var self__ = this;
var this__4437__auto____$1 = this;
return self__.__meta;
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ICloneable$_clone$arity$1 = (function (this__4434__auto__){
var self__ = this;
var this__4434__auto____$1 = this;
return (new pinkgorilla.storage.file.StorageFile(self__.filename,self__.__meta,self__.__extmap,self__.__hash));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ICounted$_count$arity$1 = (function (this__4443__auto__){
var self__ = this;
var this__4443__auto____$1 = this;
return (1 + cljs.core.count(self__.__extmap));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IHash$_hash$arity$1 = (function (this__4435__auto__){
var self__ = this;
var this__4435__auto____$1 = this;
var h__4297__auto__ = self__.__hash;
if((!((h__4297__auto__ == null)))){
return h__4297__auto__;
} else {
var h__4297__auto____$1 = (function (){var fexpr__27576 = (function (coll__4436__auto__){
return (-1049397295 ^ cljs.core.hash_unordered_coll(coll__4436__auto__));
});
return fexpr__27576(this__4435__auto____$1);
})();
(self__.__hash = h__4297__auto____$1);

return h__4297__auto____$1;
}
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (this27506,other27507){
var self__ = this;
var this27506__$1 = this;
return (((!((other27507 == null)))) && ((this27506__$1.constructor === other27507.constructor)) && (cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(this27506__$1.filename,other27507.filename)) && (cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(this27506__$1.__extmap,other27507.__extmap)));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IMap$_dissoc$arity$2 = (function (this__4448__auto__,k__4449__auto__){
var self__ = this;
var this__4448__auto____$1 = this;
if(cljs.core.contains_QMARK_(new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"filename","filename",-1428840783),null], null), null),k__4449__auto__)){
return cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(cljs.core._with_meta(cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.PersistentArrayMap.EMPTY,this__4448__auto____$1),self__.__meta),k__4449__auto__);
} else {
return (new pinkgorilla.storage.file.StorageFile(self__.filename,self__.__meta,cljs.core.not_empty(cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(self__.__extmap,k__4449__auto__)),null));
}
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IAssociative$_assoc$arity$3 = (function (this__4446__auto__,k__4447__auto__,G__27504){
var self__ = this;
var this__4446__auto____$1 = this;
var pred__27584 = cljs.core.keyword_identical_QMARK_;
var expr__27585 = k__4447__auto__;
if(cljs.core.truth_((function (){var G__27589 = new cljs.core.Keyword(null,"filename","filename",-1428840783);
var G__27590 = expr__27585;
return (pred__27584.cljs$core$IFn$_invoke$arity$2 ? pred__27584.cljs$core$IFn$_invoke$arity$2(G__27589,G__27590) : pred__27584.call(null,G__27589,G__27590));
})())){
return (new pinkgorilla.storage.file.StorageFile(G__27504,self__.__meta,self__.__extmap,null));
} else {
return (new pinkgorilla.storage.file.StorageFile(self__.filename,self__.__meta,cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(self__.__extmap,k__4447__auto__,G__27504),null));
}
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ISeqable$_seq$arity$1 = (function (this__4451__auto__){
var self__ = this;
var this__4451__auto____$1 = this;
return cljs.core.seq(cljs.core.concat.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.MapEntry(new cljs.core.Keyword(null,"filename","filename",-1428840783),self__.filename,null))], null),self__.__extmap));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IWithMeta$_with_meta$arity$2 = (function (this__4438__auto__,G__27504){
var self__ = this;
var this__4438__auto____$1 = this;
return (new pinkgorilla.storage.file.StorageFile(self__.filename,G__27504,self__.__extmap,self__.__hash));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ICollection$_conj$arity$2 = (function (this__4444__auto__,entry__4445__auto__){
var self__ = this;
var this__4444__auto____$1 = this;
if(cljs.core.vector_QMARK_(entry__4445__auto__)){
return this__4444__auto____$1.cljs$core$IAssociative$_assoc$arity$3(null,cljs.core._nth.cljs$core$IFn$_invoke$arity$2(entry__4445__auto__,(0)),cljs.core._nth.cljs$core$IFn$_invoke$arity$2(entry__4445__auto__,(1)));
} else {
return cljs.core.reduce.cljs$core$IFn$_invoke$arity$3(cljs.core._conj,this__4444__auto____$1,entry__4445__auto__);
}
}));

(pinkgorilla.storage.file.StorageFile.getBasis = (function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Symbol(null,"filename","filename",211690744,null)], null);
}));

(pinkgorilla.storage.file.StorageFile.cljs$lang$type = true);

(pinkgorilla.storage.file.StorageFile.cljs$lang$ctorPrSeq = (function (this__4482__auto__){
return (new cljs.core.List(null,"pinkgorilla.storage.file/StorageFile",null,(1),null));
}));

(pinkgorilla.storage.file.StorageFile.cljs$lang$ctorPrWriter = (function (this__4482__auto__,writer__4483__auto__){
return cljs.core._write(writer__4483__auto__,"pinkgorilla.storage.file/StorageFile");
}));

/**
 * Positional factory function for pinkgorilla.storage.file/StorageFile.
 */
pinkgorilla.storage.file.__GT_StorageFile = (function pinkgorilla$storage$file$__GT_StorageFile(filename){
return (new pinkgorilla.storage.file.StorageFile(filename,null,null,null));
});

/**
 * Factory function for pinkgorilla.storage.file/StorageFile, taking a map of keywords to field values.
 */
pinkgorilla.storage.file.map__GT_StorageFile = (function pinkgorilla$storage$file$map__GT_StorageFile(G__27514){
var extmap__4478__auto__ = (function (){var G__27602 = cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(G__27514,new cljs.core.Keyword(null,"filename","filename",-1428840783));
if(cljs.core.record_QMARK_(G__27514)){
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.PersistentArrayMap.EMPTY,G__27602);
} else {
return G__27602;
}
})();
return (new pinkgorilla.storage.file.StorageFile(new cljs.core.Keyword(null,"filename","filename",-1428840783).cljs$core$IFn$_invoke$arity$1(G__27514),null,cljs.core.not_empty(extmap__4478__auto__),null));
});

pinkgorilla.storage.storage.query_params_to_storage.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.Keyword(null,"file","file",-1269645878),(function (_,params){
return (new pinkgorilla.storage.file.StorageFile(new cljs.core.Keyword(null,"filename","filename",-1428840783).cljs$core$IFn$_invoke$arity$1(params),null,null,null));
}));
(pinkgorilla.storage.file.StorageFile.prototype.pinkgorilla$storage$storage$Storage$ = cljs.core.PROTOCOL_SENTINEL);

(pinkgorilla.storage.file.StorageFile.prototype.pinkgorilla$storage$storage$Storage$storagetype$arity$1 = (function (self){
var self__$1 = this;
return new cljs.core.Keyword(null,"file","file",-1269645878);
}));

(pinkgorilla.storage.file.StorageFile.prototype.pinkgorilla$storage$storage$Storage$external_url$arity$1 = (function (self){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.file","/tmp/form-init5318300759512683746.clj",22,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["file-storage.external-url"], null);
}),null)),null,-1108812841);

return ["file://",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.filename)].join('');
}));

(pinkgorilla.storage.file.StorageFile.prototype.pinkgorilla$storage$storage$Storage$gorilla_path$arity$1 = (function (self){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.file","/tmp/form-init5318300759512683746.clj",26,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["file-storage.gorilla-path"], null);
}),null)),null,-102715258);

return ["/edit?source=file&filename=",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.filename)].join('');
}));

//# sourceMappingURL=pinkgorilla.storage.file.js.map

==> gorilla-notebook-0.4.1.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.storage.file.js <==
goog.provide('pinkgorilla.storage.file');
goog.require('cljs.core');
goog.require('taoensso.timbre');
goog.require('pinkgorilla.storage.storage');

/**
* @constructor
 * @implements {cljs.core.IRecord}
 * @implements {cljs.core.IKVReduce}
 * @implements {cljs.core.IEquiv}
 * @implements {cljs.core.IHash}
 * @implements {cljs.core.ICollection}
 * @implements {cljs.core.ICounted}
 * @implements {cljs.core.ISeqable}
 * @implements {cljs.core.IMeta}
 * @implements {cljs.core.ICloneable}
 * @implements {cljs.core.IPrintWithWriter}
 * @implements {cljs.core.IIterable}
 * @implements {cljs.core.IWithMeta}
 * @implements {cljs.core.IAssociative}
 * @implements {cljs.core.IMap}
 * @implements {cljs.core.ILookup}
*/
pinkgorilla.storage.file.StorageFile = (function (filename,__meta,__extmap,__hash){
this.filename = filename;
this.__meta = __meta;
this.__extmap = __extmap;
this.__hash = __hash;
this.cljs$lang$protocol_mask$partition0$ = 2230716170;
this.cljs$lang$protocol_mask$partition1$ = 139264;
});
(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ILookup$_lookup$arity$2 = (function (this__4439__auto__,k__4440__auto__){
var self__ = this;
var this__4439__auto____$1 = this;
return this__4439__auto____$1.cljs$core$ILookup$_lookup$arity$3(null,k__4440__auto__,null);
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ILookup$_lookup$arity$3 = (function (this__4441__auto__,k53094,else__4442__auto__){
var self__ = this;
var this__4441__auto____$1 = this;
var G__53098 = k53094;
var G__53098__$1 = (((G__53098 instanceof cljs.core.Keyword))?G__53098.fqn:null);
switch (G__53098__$1) {
case "filename":
return self__.filename;

break;
default:
return cljs.core.get.cljs$core$IFn$_invoke$arity$3(self__.__extmap,k53094,else__4442__auto__);

}
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IKVReduce$_kv_reduce$arity$3 = (function (this__4458__auto__,f__4459__auto__,init__4460__auto__){
var self__ = this;
var this__4458__auto____$1 = this;
return cljs.core.reduce.cljs$core$IFn$_invoke$arity$3((function (ret__4461__auto__,p__53099){
var vec__53100 = p__53099;
var k__4462__auto__ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__53100,(0),null);
var v__4463__auto__ = cljs.core.nth.cljs$core$IFn$_invoke$arity$3(vec__53100,(1),null);
return (f__4459__auto__.cljs$core$IFn$_invoke$arity$3 ? f__4459__auto__.cljs$core$IFn$_invoke$arity$3(ret__4461__auto__,k__4462__auto__,v__4463__auto__) : f__4459__auto__.call(null,ret__4461__auto__,k__4462__auto__,v__4463__auto__));
}),init__4460__auto__,this__4458__auto____$1);
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IPrintWithWriter$_pr_writer$arity$3 = (function (this__4453__auto__,writer__4454__auto__,opts__4455__auto__){
var self__ = this;
var this__4453__auto____$1 = this;
var pr_pair__4456__auto__ = (function (keyval__4457__auto__){
return cljs.core.pr_sequential_writer(writer__4454__auto__,cljs.core.pr_writer,""," ","",opts__4455__auto__,keyval__4457__auto__);
});
return cljs.core.pr_sequential_writer(writer__4454__auto__,pr_pair__4456__auto__,"#pinkgorilla.storage.file.StorageFile{",", ","}",opts__4455__auto__,cljs.core.concat.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.PersistentVector(null,2,(5),cljs.core.PersistentVector.EMPTY_NODE,[new cljs.core.Keyword(null,"filename","filename",-1428840783),self__.filename],null))], null),self__.__extmap));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IIterable$_iterator$arity$1 = (function (G__53093){
var self__ = this;
var G__53093__$1 = this;
return (new cljs.core.RecordIter((0),G__53093__$1,1,new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Keyword(null,"filename","filename",-1428840783)], null),(cljs.core.truth_(self__.__extmap)?cljs.core._iterator(self__.__extmap):cljs.core.nil_iter())));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IMeta$_meta$arity$1 = (function (this__4437__auto__){
var self__ = this;
var this__4437__auto____$1 = this;
return self__.__meta;
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ICloneable$_clone$arity$1 = (function (this__4434__auto__){
var self__ = this;
var this__4434__auto____$1 = this;
return (new pinkgorilla.storage.file.StorageFile(self__.filename,self__.__meta,self__.__extmap,self__.__hash));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ICounted$_count$arity$1 = (function (this__4443__auto__){
var self__ = this;
var this__4443__auto____$1 = this;
return (1 + cljs.core.count(self__.__extmap));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IHash$_hash$arity$1 = (function (this__4435__auto__){
var self__ = this;
var this__4435__auto____$1 = this;
var h__4297__auto__ = self__.__hash;
if((!((h__4297__auto__ == null)))){
return h__4297__auto__;
} else {
var h__4297__auto____$1 = (function (){var fexpr__53103 = (function (coll__4436__auto__){
return (-1049397295 ^ cljs.core.hash_unordered_coll(coll__4436__auto__));
});
return fexpr__53103(this__4435__auto____$1);
})();
(self__.__hash = h__4297__auto____$1);

return h__4297__auto____$1;
}
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IEquiv$_equiv$arity$2 = (function (this53095,other53096){
var self__ = this;
var this53095__$1 = this;
return (((!((other53096 == null)))) && ((this53095__$1.constructor === other53096.constructor)) && (cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(this53095__$1.filename,other53096.filename)) && (cljs.core._EQ_.cljs$core$IFn$_invoke$arity$2(this53095__$1.__extmap,other53096.__extmap)));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IMap$_dissoc$arity$2 = (function (this__4448__auto__,k__4449__auto__){
var self__ = this;
var this__4448__auto____$1 = this;
if(cljs.core.contains_QMARK_(new cljs.core.PersistentHashSet(null, new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"filename","filename",-1428840783),null], null), null),k__4449__auto__)){
return cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(cljs.core._with_meta(cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.PersistentArrayMap.EMPTY,this__4448__auto____$1),self__.__meta),k__4449__auto__);
} else {
return (new pinkgorilla.storage.file.StorageFile(self__.filename,self__.__meta,cljs.core.not_empty(cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(self__.__extmap,k__4449__auto__)),null));
}
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IAssociative$_assoc$arity$3 = (function (this__4446__auto__,k__4447__auto__,G__53093){
var self__ = this;
var this__4446__auto____$1 = this;
var pred__53104 = cljs.core.keyword_identical_QMARK_;
var expr__53105 = k__4447__auto__;
if(cljs.core.truth_((function (){var G__53107 = new cljs.core.Keyword(null,"filename","filename",-1428840783);
var G__53108 = expr__53105;
return (pred__53104.cljs$core$IFn$_invoke$arity$2 ? pred__53104.cljs$core$IFn$_invoke$arity$2(G__53107,G__53108) : pred__53104.call(null,G__53107,G__53108));
})())){
return (new pinkgorilla.storage.file.StorageFile(G__53093,self__.__meta,self__.__extmap,null));
} else {
return (new pinkgorilla.storage.file.StorageFile(self__.filename,self__.__meta,cljs.core.assoc.cljs$core$IFn$_invoke$arity$3(self__.__extmap,k__4447__auto__,G__53093),null));
}
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ISeqable$_seq$arity$1 = (function (this__4451__auto__){
var self__ = this;
var this__4451__auto____$1 = this;
return cljs.core.seq(cljs.core.concat.cljs$core$IFn$_invoke$arity$2(new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [(new cljs.core.MapEntry(new cljs.core.Keyword(null,"filename","filename",-1428840783),self__.filename,null))], null),self__.__extmap));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$IWithMeta$_with_meta$arity$2 = (function (this__4438__auto__,G__53093){
var self__ = this;
var this__4438__auto____$1 = this;
return (new pinkgorilla.storage.file.StorageFile(self__.filename,G__53093,self__.__extmap,self__.__hash));
}));

(pinkgorilla.storage.file.StorageFile.prototype.cljs$core$ICollection$_conj$arity$2 = (function (this__4444__auto__,entry__4445__auto__){
var self__ = this;
var this__4444__auto____$1 = this;
if(cljs.core.vector_QMARK_(entry__4445__auto__)){
return this__4444__auto____$1.cljs$core$IAssociative$_assoc$arity$3(null,cljs.core._nth.cljs$core$IFn$_invoke$arity$2(entry__4445__auto__,(0)),cljs.core._nth.cljs$core$IFn$_invoke$arity$2(entry__4445__auto__,(1)));
} else {
return cljs.core.reduce.cljs$core$IFn$_invoke$arity$3(cljs.core._conj,this__4444__auto____$1,entry__4445__auto__);
}
}));

(pinkgorilla.storage.file.StorageFile.getBasis = (function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, [new cljs.core.Symbol(null,"filename","filename",211690744,null)], null);
}));

(pinkgorilla.storage.file.StorageFile.cljs$lang$type = true);

(pinkgorilla.storage.file.StorageFile.cljs$lang$ctorPrSeq = (function (this__4482__auto__){
return (new cljs.core.List(null,"pinkgorilla.storage.file/StorageFile",null,(1),null));
}));

(pinkgorilla.storage.file.StorageFile.cljs$lang$ctorPrWriter = (function (this__4482__auto__,writer__4483__auto__){
return cljs.core._write(writer__4483__auto__,"pinkgorilla.storage.file/StorageFile");
}));

/**
 * Positional factory function for pinkgorilla.storage.file/StorageFile.
 */
pinkgorilla.storage.file.__GT_StorageFile = (function pinkgorilla$storage$file$__GT_StorageFile(filename){
return (new pinkgorilla.storage.file.StorageFile(filename,null,null,null));
});

/**
 * Factory function for pinkgorilla.storage.file/StorageFile, taking a map of keywords to field values.
 */
pinkgorilla.storage.file.map__GT_StorageFile = (function pinkgorilla$storage$file$map__GT_StorageFile(G__53097){
var extmap__4478__auto__ = (function (){var G__53109 = cljs.core.dissoc.cljs$core$IFn$_invoke$arity$2(G__53097,new cljs.core.Keyword(null,"filename","filename",-1428840783));
if(cljs.core.record_QMARK_(G__53097)){
return cljs.core.into.cljs$core$IFn$_invoke$arity$2(cljs.core.PersistentArrayMap.EMPTY,G__53109);
} else {
return G__53109;
}
})();
return (new pinkgorilla.storage.file.StorageFile(new cljs.core.Keyword(null,"filename","filename",-1428840783).cljs$core$IFn$_invoke$arity$1(G__53097),null,cljs.core.not_empty(extmap__4478__auto__),null));
});

pinkgorilla.storage.storage.query_params_to_storage.cljs$core$IMultiFn$_add_method$arity$3(null,new cljs.core.Keyword(null,"file","file",-1269645878),(function (_,params){
return (new pinkgorilla.storage.file.StorageFile(new cljs.core.Keyword(null,"filename","filename",-1428840783).cljs$core$IFn$_invoke$arity$1(params),null,null,null));
}));
(pinkgorilla.storage.file.StorageFile.prototype.pinkgorilla$storage$storage$Storage$ = cljs.core.PROTOCOL_SENTINEL);

(pinkgorilla.storage.file.StorageFile.prototype.pinkgorilla$storage$storage$Storage$storagetype$arity$1 = (function (self){
var self__$1 = this;
return new cljs.core.Keyword(null,"file","file",-1269645878);
}));

(pinkgorilla.storage.file.StorageFile.prototype.pinkgorilla$storage$storage$Storage$external_url$arity$1 = (function (self){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.file","/tmp/form-init7190841119320184072.clj",20,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["file-storage.external-url"], null);
}),null)),null,296306287);

return ["file://",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.filename)].join('');
}));

(pinkgorilla.storage.file.StorageFile.prototype.pinkgorilla$storage$storage$Storage$gorilla_path$arity$1 = (function (self){
var self__$1 = this;
taoensso.timbre._log_BANG_.cljs$core$IFn$_invoke$arity$10(taoensso.timbre._STAR_config_STAR_,new cljs.core.Keyword(null,"info","info",-317069002),"pinkgorilla.storage.file","/tmp/form-init7190841119320184072.clj",24,new cljs.core.Keyword(null,"p","p",151049309),new cljs.core.Keyword(null,"auto","auto",-566279492),(new cljs.core.Delay((function (){
return new cljs.core.PersistentVector(null, 1, 5, cljs.core.PersistentVector.EMPTY_NODE, ["file-storage.gorilla-path"], null);
}),null)),null,792086511);

return ["/edit?source=file&filename=",cljs.core.str.cljs$core$IFn$_invoke$arity$1(self__$1.filename)].join('');
}));

//# sourceMappingURL=pinkgorilla.storage.file.js.map
